@@ -8,6 +8,14 @@ import weakref
 
 from rdkit.Chem import MolToSmiles, MolFromSmiles, BondType, GetSymmSSSR
 
+try:
+    kernel_name = get_ipython().__class__.__name__
+    if kernel_name == 'ZMQInteractiveShell':
+        from rdkit.Chem.Draw import IPythonConsole
+        from rdkit.Chem import Draw
+except NameError:
+    pass
+
 
 class Scaffold(object):
     """A convenience class for defining scaffolds in scaffoldgraph.
@@ -210,6 +218,13 @@ class Scaffold(object):
             return self.hash_func(self.mol)
         return self.smiles
 
+    def clear_cached_attributes(self):
+        """Clear all cached attributes."""
+        setattr(self, '_atoms', None)
+        setattr(self, '_bonds', None)
+        setattr(self, '_rings', None)
+        setattr(self, '_ring_systems', None)
+
     @classmethod
     def from_smiles(cls, smiles, hash_func=None):
         """Construct a Scaffold object from a SMILES string.
@@ -243,10 +258,7 @@ class Scaffold(object):
 
     def __setstate__(self, state):
         self.mol, self.hash_func = state
-        setattr(self, '_atoms', None)
-        setattr(self, '_bonds', None)
-        setattr(self, '_rings', None)
-        setattr(self, '_ring_systems', None)
+        self.clear_cached_attributes()
 
     def __bool__(self):
         """Returns True if the molecule contains at least 1 atom."""
@@ -267,6 +279,20 @@ class Scaffold(object):
         """Returns the SMILES string of the molecule."""
         return self.smiles
 
+    def _repr_png_(self):
+        """Return PNG representation of the rdkit mol."""
+        try:
+            return self.mol._repr_png_()
+        except AttributeError:
+            return None
+
+    def _repr_svg_(self):
+        """Return SVG representation of the rdkit mol."""
+        try:
+            return self.mol._repr_svg_()
+        except AttributeError:
+            return None
+
     def __repr__(self):
         return '<{_cls} at {address}>'.format(
             _cls=self.__class__.__name__,
@@ -483,6 +509,29 @@ class Ring(object):
         """Returns the size of the ring (number of atoms)."""
         return len(self.aix)
 
+    def _repr_png_(self):
+        """Return PNG representation of the rdkit mol (ring highlighted)."""
+        mol = self.owner.mol
+        keku = IPythonConsole.kekulizeStructures
+        size = IPythonConsole.molSize
+        opts = IPythonConsole.drawOptions
+        return Draw._moltoimg(
+            mol, size, self.aix, "", returnPNG=True, drawOptions=opts,
+            kekulize=keku, highlightBonds=self.bix
+        )
+
+    def _repr_svg_(self):
+        """Return SVG representation of the rdkit mol (ring highlighted)."""
+        if not IPythonConsole.ipython_useSVG:
+            return None
+        mol = self.owner.mol
+        keku = IPythonConsole.kekulizeStructures
+        size = IPythonConsole.molSize
+        opts = IPythonConsole.drawOptions
+        return Draw._moltoSVG(
+            mol, size, self.aix, "", keku, drawOptions=opts, highlightBonds=self.bix
+        )
+
     def __repr__(self):
         return '<{_cls} at {address}>'.format(
             _cls=self.__class__.__name__,
@@ -824,6 +873,29 @@ class RingSystem(object):
     def __len__(self):
         return len(self.aix)
 
+    def _repr_png_(self):
+        """Return PNG representation of the rdkit mol (ring highlighted)."""
+        mol = self.owner.mol
+        keku = IPythonConsole.kekulizeStructures
+        size = IPythonConsole.molSize
+        opts = IPythonConsole.drawOptions
+        return Draw._moltoimg(
+            mol, size, self.aix, "", returnPNG=True, drawOptions=opts,
+            kekulize=keku, highlightBonds=self.bix
+        )
+
+    def _repr_svg_(self):
+        """Return SVG representation of the rdkit mol (ring highlighted)."""
+        if not IPythonConsole.ipython_useSVG:
+            return None
+        mol = self.owner.mol
+        keku = IPythonConsole.kekulizeStructures
+        size = IPythonConsole.molSize
+        opts = IPythonConsole.drawOptions
+        return Draw._moltoSVG(
+            mol, size, self.aix, "", keku, drawOptions=opts, highlightBonds=self.bix
+        )
+
     def __repr__(self):
         return '<{_cls} at {address}>'.format(
             _cls=self.__class__.__name__,
